@@ -1,15 +1,18 @@
+from __future__ import print_function, division
+
 import os
-from tools import download_with_progress_bar
 from gzip import GzipFile
-from cStringIO import StringIO
 
 import numpy as np
+
+from .tools import download_with_progress_bar
+from ..py3k_compat import BytesIO
 from . import get_data_home
 
-DATA_URL = ('http://www.astro.washington.edu/users/ivezic/'
-            'sdss/catalogs/stripe82calibStars_v2.6.dat.gz')
-DATA_URL_2MASS = ('http://www.astro.washington.edu/users/ivezic/'
-                  'sdss/catalogs/stripe82calibStars_2MASS_v2.6.dat.gz')
+DATA_URL = ('https://github.com/astroML/astroML-data/raw/master/datasets/'
+            'stripe82calibStars_v2.6.dat.gz')
+DATA_URL_2MASS = ('https://github.com/astroML/astroML-data/raw/master/datasets/'
+                  'stripe82calibStars_2MASS_v2.6.dat.gz')
 
 ARCHIVE_FILE = 'sdss_S82standards.npy'
 ARCHIVE_FILE_2MASS = 'sdss_S82standards_2mass.npy'
@@ -48,7 +51,7 @@ def fetch_sdss_S82standards(data_home=None, download_if_missing=True,
     ----------
     data_home : optional, default=None
         Specify another download and cache folder for the datasets. By default
-        all scikit learn data is stored in '~/astroML_data' subfolders.
+        all astroML data is stored in '~/astroML_data'.
 
     download_if_missing : bool, optional, default=True
         If False, raise a IOError if the data is not locally available
@@ -100,18 +103,16 @@ def fetch_sdss_S82standards(data_home=None, download_if_missing=True,
 
     Examples
     --------
-    >>> data = fetch_sdss_S82standards()
-    >>> u_g = data['mmed_u'] - data['mmed_g']
-    >>> print u_g[:5]
-    [-22.23500061   1.34900093   1.43799973   2.08200073 -23.03800011]
+    >>> data = fetch_sdss_S82standards()  # doctest: +IGNORE_OUTPUT +REMOTE_DATA
+    >>> u_g = data['mmed_u'] - data['mmed_g']  # doctest: +REMOTE_DATA
+    >>> print(u_g[:4])  # doctest: +REMOTE_DATA
+    [-22.23500061   1.34900093   1.43799973   2.08200073]
 
     References
     ----------
     Ivesic et al. ApJ 134:973 (2007)
     """
     data_home = get_data_home(data_home)
-    if not os.path.exists(data_home):
-        os.makedirs(data_home)
 
     if crossmatch_2mass:
         archive_file = os.path.join(data_home, ARCHIVE_FILE_2MASS)
@@ -128,13 +129,13 @@ def fetch_sdss_S82standards(data_home=None, download_if_missing=True,
             raise IOError('data not present on disk. '
                           'set download_if_missing=True to download')
 
-        print ("downloading cross-matched SDSS/2MASS dataset from %s to %s"
-               % (data_url, data_home))
+        print("downloading cross-matched SDSS/2MASS dataset from %s to %s"
+              % (data_url, data_home))
 
         zipped_buf = download_with_progress_bar(data_url, return_buffer=True)
         gzf = GzipFile(fileobj=zipped_buf, mode='rb')
-        print "uncompressing file..."
-        extracted_buf = StringIO(gzf.read())
+        print("uncompressing file...")
+        extracted_buf = BytesIO(gzf.read())
         data = np.loadtxt(extracted_buf, **kwargs)
         np.save(archive_file, data)
 
