@@ -7,13 +7,15 @@ http://arxiv.org/pdf/0905.2979v2.pdf
 Arbitrary mixing matrices R are not yet implemented: currently, this only
 works with R = I.
 """
+from __future__ import print_function, division
+
 from time import time
 
 import numpy as np
 from scipy import linalg
 
-from sklearn.mixture import GMM
-from astroML.utils import logsumexp, log_multivariate_gaussian
+from sklearn.mixture import GaussianMixture
+from ..utils import logsumexp, log_multivariate_gaussian, check_random_state
 
 
 class XDGMM(object):
@@ -25,7 +27,7 @@ class XDGMM(object):
     ----------
     n_components: integer
         number of gaussian components to fit to the data
-    n_iter: integer (optional)
+    max_iter: integer (optional)
         number of EM iterations to perform (default=100)
     tol: float (optional)
         stopping criterion for EM iterations (default=1E-5)
@@ -34,11 +36,13 @@ class XDGMM(object):
     -----
     This implementation follows Bovy et al. arXiv 0905.2979
     """
-    def __init__(self, n_components, n_iter=100, tol=1E-5, verbose=False):
+    def __init__(self, n_components, max_iter=100, tol=1E-5, verbose=False,
+                 random_state = None):
         self.n_components = n_components
-        self.n_iter = n_iter
+        self.max_iter = max_iter
         self.tol = tol
         self.verbose = verbose
+        self.random_state = random_state
 
         # model parameters: these are set by the fit() method
         self.V = None
@@ -69,24 +73,26 @@ class XDGMM(object):
         # assume full covariances of data
         assert Xerr.shape == (n_samples, n_features, n_features)
 
-        # initialize components via a few steps of GMM
+        # initialize components via a few steps of GaussianMixture
         # this doesn't take into account errors, but is a fast first-guess
-        gmm = GMM(self.n_components, n_iter=10, covariance_type='full').fit(X)
+        gmm = GaussianMixture(self.n_components, max_iter=10,
+                              covariance_type='full',
+                              random_state=self.random_state).fit(X)
         self.mu = gmm.means_
         self.alpha = gmm.weights_
-        self.V = gmm.covars_
+        self.V = gmm.covariances_
 
         logL = self.logL(X, Xerr)
 
-        for i in range(self.n_iter):
+        for i in range(self.max_iter):
             t0 = time()
             self._EMstep(X, Xerr)
             logL_next = self.logL(X, Xerr)
             t1 = time()
 
             if self.verbose:
-                print "%i: log(L) = %.5g" % (i + 1, logL_next)
-                print "    (%.2g sec)" % (t1 - t0)
+                print("%i: log(L) = %.5g" % (i + 1, logL_next))
+                print("    (%.2g sec)" % (t1 - t0))
 
             if logL_next < logL + self.tol:
                 break
@@ -121,7 +127,7 @@ class XDGMM(object):
         Xerr = Xerr[:, np.newaxis, :, :]
         T = Xerr + self.V
 
-        return log_multivariate_gaussian(X, self.mu, T)
+        return log_multivariate_gaussian(X, self.mu, T) + np.log(self.alpha)
 
     def logL(self, X, Xerr):
         """Compute the log-likelihood of data given the model
@@ -194,7 +200,10 @@ class XDGMM(object):
         tmp *= q[:, :, np.newaxis, np.newaxis]
         self.V = tmp.sum(0) / qj[:, np.newaxis, np.newaxis]
 
-    def sample(self, size=1):
+    def sample(self, size=1, random_state=None):
+        if random_state is None:
+            random_state = self.random_state
+        rng = check_random_state(random_state)
         shape = tuple(np.atleast_1d(size)) + (self.mu.shape[1],)
         npts = np.prod(size)
 
